@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -55,11 +55,11 @@ __all__ = (
 ArrayValueTypeDef = TypedDict(
     "ArrayValueTypeDef",
     {
-        "arrayValues": List[Dict[str, Any]],
-        "booleanValues": List[bool],
-        "doubleValues": List[float],
-        "longValues": List[int],
-        "stringValues": List[str],
+        "arrayValues": Sequence[Dict[str, Any]],
+        "booleanValues": Sequence[bool],
+        "doubleValues": Sequence[float],
+        "longValues": Sequence[int],
+        "stringValues": Sequence[str],
     },
     total=False,
 )
@@ -76,7 +76,7 @@ _OptionalBatchExecuteStatementRequestRequestTypeDef = TypedDict(
     "_OptionalBatchExecuteStatementRequestRequestTypeDef",
     {
         "database": str,
-        "parameterSets": List[List["SqlParameterTypeDef"]],
+        "parameterSets": Sequence[Sequence["SqlParameterTypeDef"]],
         "schema": str,
         "transactionId": str,
     },
@@ -214,7 +214,7 @@ _OptionalExecuteStatementRequestRequestTypeDef = TypedDict(
         "continueAfterTimeout": bool,
         "database": str,
         "includeResultMetadata": bool,
-        "parameters": List["SqlParameterTypeDef"],
+        "parameters": Sequence["SqlParameterTypeDef"],
         "resultSetOptions": "ResultSetOptionsTypeDef",
         "schema": str,
         "transactionId": str,
@@ -338,7 +338,7 @@ SqlStatementResultTypeDef = TypedDict(
 StructValueTypeDef = TypedDict(
     "StructValueTypeDef",
     {
-        "attributes": List[Dict[str, Any]],
+        "attributes": List["ValueTypeDef"],
     },
     total=False,
 )
